@@ -16,11 +16,11 @@ VKontakte::API - Module for login into vkontakte.ru and sending requests
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -32,6 +32,15 @@ our $VERSION = '0.02';
     my $vk = VKontakte::API->new('api_id', 'secret_key');
     my $data=$vk->sendRequest('getProfiles', {'domains'=>'deevaas'});
 
+    #or
+    $vk = VKontakte::API->new(
+        $api_id,
+        $cgi_query->param('session[secret]'),
+        $cgi_query->param('session[mid]'),
+        $cgi_query->param('session[sid]')
+    );
+    
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -105,7 +114,7 @@ sub sendRequest {
 	$params->{'sid'} = $self->{sid} if $self->{sid};
 	my $query = $self->{api_url} . '?' . $self->_params($params);
 
-	my $mech = WWW::Mechanize->new( agent => 'VKontakte::Auth', );
+	my $mech = WWW::Mechanize->new( agent => 'VKontakte::API', );
 	my $r = $mech->get($query);
 
 	#	my $res      = file_get_contents($query);
